import { MediaTypes } from '../types';
/**
 * This class allows access to the details of incoming Conference invitation.
 * This class must not be directly instantiated. Instead,
 * instances of this class are obtained by calling the {@link Conference#getInvite}
 */
export declare class ConferenceInvite {
    private id;
    private from;
    private mediaTypes;
    private context;
    /** @ignore */
    constructor(id: string, from: string, mediaTypes: MediaTypes, context?: object);
    /**
     * @desc Obtains the ID of the incoming invitation
     * @returns {string}
     */
    getId(): string;
    /**
     * @desc Obtains the "gateway" of the caller. This can be a user's gateway or pstn number.
     * @returns {string}
     */
    getFrom(): string;
    /**
     * @desc Obtains the mediaTypes for this conference invite.
     * This allow us to guess if we are invited with audio & video, or only with audio and video
     * @returns {MediaTypes}
     */
    getMediaTypes(): MediaTypes;
    /**
     * @desc Obtains the context for this conference invite.
     * The context is created by the user placing the invite and it will usually contain extra information
     * about the caller
     * @returns {object}
     */
    getContext(): object;
}
